#!/bin/bash

PRELEASE="indt3"
PNAME="efl-core"
PVER="$(grep AM_INIT_AUTOMAKE evas/configure.in | sed 's/AM_INIT_AUTOMAKE(evas, \([^)]\+\))/\1/')_${PRELEASE}"
SECTION="libs"

#DEF_PKGS="imlib2 eet edb imlib2_loaders evas ecore epeg embryo edje epsilon esmart efreet ewl emotion engrave etk exml enhance "
DEF_PKGS="eet evas ecore embryo edje"

DESC="Enlightenment Foundation Libraries Core"
LONG_DESC="\
 This package includes: $DEF_PKGS
 .
 Homepage: http://www.enlightenment.org/
"
BDEPENDS="pkg-config, libfreetype6-dev, zlib1g-dev, libjpeg62-dev, libexpat1-dev, libssl-dev, libcurl3-openssl-dev, libxdamage-dev"
DEPENDS="libfreetype6, zlib1g, libjpeg62, libexpat1, libssl0.9.7, libcurl3, libxdamage1"

OPTS_evas="--enable-software-16-x11 --enable-software-x11 --disable-scale-smooth --disable-pthreads --enable-no-dither-mask --enable-small-dither-mask --disable-fb --disable-xrender-x11 --disable-image-loader-tiff --disable-image-loader-edb --disable-image-loader-gif --disable-image-loader-xpm --disable-image-loader-svg --disable-convert-yuv --disable-convert-8-rgb-332 --disable-convert-8-rgb-666 --disable-convert-8-rgb-232 --disable-convert-8-rgb-222 --disable-convert-8-rgb-221 --disable-convert-8-rgb-121 --disable-convert-8-rgb-111 --disable-convert-16-bgr-565 --disable-convert-16-rgb-555 --disable-convert-16-rgb-444 --disable-convert-16-rgb-ipq --disable-convert-16-rgb-rot-180 --disable-convert-16-rgb-rot-270 --disable-convert-16-rgb-rot-90 --disable-convert-24-rgb-888 --disable-convert-24-bgr-888 --disable-convert-32-rgb-8888 --disable-convert-32-rgbx-8888 --disable-convert-32-bgr-8888 --disable-convert-32-bgrx-8888 --disable-convert-32-rgb-rot-0 --disable-convert-32-rgb-rot-180 --disable-convert-32-rgb-rot-270 --disable-convert-32-rgb-rot-90"

OPTS_ecore="--enable-ecore-evas-x11-16 --disable-ecore-fb --disable-ecore-directfb --disable-ecore-evas-gl --disable-ecore-evas-dfb --disable-ecore-evas-xrender --disable-ecore-evas-fb"

ARCH="$(arch)"

export CFLAGS="$CFLAGS -DNDEBUG=1 -fomit-frame-pointer -O2 -mfpu=vfp -mfloat-abi=softfp -mcpu=arm1136jf-s -ffast-math -funsafe-math-optimizations -fno-math-errno -fsingle-precision-constant"
DESTDIR="/tmp/$PNAME-$ARCH"

PKGS="$@"
if [ x"$PKGS" = x ]; then
	PKGS=$DEF_PKGS
fi

die() {
	echo "ERROR: $@"
	exit 1
}

if [ x"$NODESTDIR" != x1 ]; then
    rm -fr $DESTDIR
fi

LOG_PREFIX="$(basename $0)"

CWD=$PWD
for p in $PKGS; do
    PKG_OPTS_NAME="OPTS_$p"
    PKG_OPTS="${!PKG_OPTS_NAME}"
    LOG="/tmp/${LOG_PREFIX}__$p.log"

    echo "Build: $p"
    echo "$(date) ---- $p" >> "$LOG"
    cd $CWD/$p || die "missing package $p"

    if [ x"$NORECONFIGURE" != x1 ]; then
        if [ -f Makefile ] && [  x"$NOMAKE" != x1 ]; then
            (make uninstall && make distclean) >/dev/null 2>> "$LOG"
        fi
	libtoolize --copy --force >/dev/null 2>> "$LOG" || die "failed to run libtoolize $p"
        NOCONFIGURE=1 ./autogen.sh >/dev/null 2>> "$LOG" || die "failed to autogen.sh $p"

        OPTS="--prefix=/usr"
        ./configure $OPTS $PKG_OPTS >/dev/null 2>> "$LOG" || die "failed to configure $p"
    fi

    if [ x"$NOMAKE" != x1 ]; then
        make >/dev/null 2>> "$LOG" || die "failed to make $p"
        make install >/dev/null 2>> "$LOG" || die "failed to install $p"
    fi

    if [ x"$NODESTDIR" != x1 ]; then
        make DESTDIR=$DESTDIR install >/dev/null 2>> "$LOG"
    fi
    cd $CWD
done

if [ x"$NODESTDIR" != x1 ]; then
    cd $DESTDIR
    tar czf $DESTDIR.tar.gz .
    cd $CWD
fi

##
## Clean
##
find $DESTDIR/usr/lib -name '*.a' -exec rm \{\} \;
find $DESTDIR/usr/lib -name '*.la' -exec rm \{\} \;
find $DESTDIR/usr/lib -name '*.so' -exec strip -s \{\} \;
rm -fr $DESTDIR/usr/include
rm -fr $DESTDIR/usr/bin/*-config
rm -fr $DESTDIR/usr/lib/pkgconfig
SIZE=$(du -sc $DESTDIR | grep total | sed s/total//)

##
## Package
##
PDIR="${DESTDIR}-deb"
mkdir -p $PDIR
cd $PDIR
cat > control <<EOF
Package: $PNAME
Version: $PVER
Section: $SECTION
Priority: optional
Architecture: armel
Installed-Size: $SIZE
Maintainer: Gustavo Sverzut Barbieri <gustavo.barbieri@openbossa.org>
Build-Depends: $BDEPENDS
Depends: $DEPENDS
Description: $DESC
$LONG_DESC
EOF
echo 2.0 > debian-binary
tar czf control.tar.gz control
(cd $DESTDIR; tar czf $PDIR/data.tar.gz .)
rm -f ${PNAME}_${PVER}.deb
ar q ${PNAME}_${PVER}_armel.deb debian-binary control.tar.gz data.tar.gz
echo $PWD/${PNAME}_${PVER}_armel.deb
